@@ -25,7 +25,7 @@ const IRC_SCHEMA_REGEX = /^(irc?:\/\/)([\da-z\.-]+):?(\d+)?\/(?:%23)?([\w\.\+-]+
 const AUTOSTART_DIR = GLib.get_user_config_dir() + '/autostart';
 const AUTOSTART_FILE = '/org.gnome.Polari.Autostart.desktop';
 
-const Application = new Lang.Class({
+var Application = new Lang.Class({
     Name: 'Application',
     Extends: Gtk.Application,
     Signals: { 'prepare-shutdown': {},
@@ -528,6 +528,11 @@ const Application = new Lang.Class({
                 let strReasons = Object.keys(Tp.ConnectionStatusReason);
                 debug('Account %s disconnected with reason %s'.format(
                       account.display_name, strReasons[reason]));
+
+                // Connection failed, keep tp from retrying over and over
+                let presence = Tp.ConnectionPresenceType.OFFLINE;
+                let msg = account.requested_status_message;
+                account.request_presence_async(presence, 'offline', msg, null);
             }
         }
 
@@ -651,7 +656,8 @@ const Application = new Lang.Class({
                 'Isabella Ribeiro <belinhacbr@gmail.com>',
                 'Jonas Danielsson <jonas@threetimestwo.org>',
                 'Rares Visalom <rares.visalom@gmail.com>',
-                'Danny Mølgaard <moelgaard.dmp@gmail.com>'
+                'Danny Mølgaard <moelgaard.dmp@gmail.com>',
+                'Justyn Temme <Justyntemme@gmail.com>'
             ],
             artists: [
                 'Sam Hewitt <hewittsamuel@gmail.com>',
