@@ -10,7 +10,7 @@ const Utils = imports.utils;
 
 const N_ = s => s;
 
-const knownCommands = {
+var knownCommands = {
     /* commands that would be nice to support: */
     /*
     AWAY: N_("/AWAY [<message>] — sets or unsets away message"),
@@ -39,7 +39,7 @@ const knownCommands = {
 const UNKNOWN_COMMAND_MESSAGE =
     N_("Unknown command — try /HELP for a list of available commands");
 
-const IrcParser = new Lang.Class({
+var IrcParser = new Lang.Class({
     Name: 'IrcParser',
 
     _init: function(room) {
