@@ -44,7 +44,7 @@ const SASLAbortReason = {
     USER_ABORT: 1
 };
 
-const SASLAuthHandler = new Lang.Class({
+var SASLAuthHandler = new Lang.Class({
     Name: 'SASLAuthHandler',
 
     _init: function(channel) {
@@ -109,7 +109,7 @@ const SASLAuthHandler = new Lang.Class({
     }
 });
 
-const TelepathyClient = new Lang.Class({
+var TelepathyClient = new Lang.Class({
     Name: 'TelepathyClient',
     Extends: Tp.BaseClient,
 
@@ -193,25 +193,24 @@ const TelepathyClient = new Lang.Class({
         this._accountsMonitor.connect('account-enabled', (mon, account) => {
             this._connectAccount(account);
         });
+        this._accountsMonitor.enabledAccounts.forEach(a => {
+            this._onAccountStatusChanged(this._accountsMonitor, a);
+        });
 
-        this._networkMonitor.connect('notify::network-available',
-                                     Lang.bind(this, this._onNetworkAvailableChanged));
-        this._onNetworkAvailableChanged();
+        this._networkMonitor.connect('network-changed',
+                                     Lang.bind(this, this._onNetworkChanged));
+        this._onNetworkChanged(this._networkMonitor,
+                               this._networkMonitor.network_available);
     },
 
-    _onNetworkAvailableChanged: function() {
-        let connected = this._networkMonitor.network_available;
+    _onNetworkChanged: function(mon, connected) {
         let presence = connected ? Tp.ConnectionPresenceType.AVAILABLE
                                  : Tp.ConnectionPresenceType.OFFLINE;
         debug('Network changed to %s'.format(connected ? 'available'
                                                        : 'unavailable'));
 
         this._accountsMonitor.enabledAccounts.forEach(a => {
-            if (a.requested_presence_type == Tp.ConnectionPresenceType.AVAILABLE &&
-                a.connection_status == Tp.ConnectionStatus.CONNECTED)
-                this._onAccountStatusChanged(this._accountsMonitor, a);
-            else
-                this._setAccountPresence(a, presence);
+            this._setAccountPresence(a, presence);
         });
     },
 
@@ -301,6 +300,7 @@ const TelepathyClient = new Lang.Class({
         let params = account.dup_parameters_vardict().deep_unpack();
         let username = settings.get_string('identify-username') ||
                        params.username.deep_unpack();
+        let alwaysSendUsername = settings.get_boolean('identify-username-supported');
         let contactName = settings.get_string('identify-botname');
         let command = settings.get_string('identify-command');
         this._requestChannel(account, Tp.HandleType.CONTACT, contactName,
@@ -309,6 +309,11 @@ const TelepathyClient = new Lang.Class({
                     return;
 
                 let room = this._roomManager.lookupRoomByChannel(channel);
+                let activeNick = room.channel.connection.self_contact.alias;
+                // Omit username parameter when it matches the default, to
+                // support NickServ bots that don't support the parameter at all
+                if (!alwaysSendUsername && activeNick == username)
+                    username = null;
                 room.send_identify_message_async(command, username, password, (r, res) => {
                     try {
                         r.send_identify_message_finish(res);
@@ -436,6 +441,7 @@ const TelepathyClient = new Lang.Class({
             settings.set_string('identify-command', data.command);
 
         settings.set_string('identify-username', data.username);
+        settings.set_boolean('identify-username-supported', data.usernameSupported);
     },
 
     _onDiscardIdentifyPasswordActivated: function(action, parameter) {
@@ -556,6 +562,7 @@ const TelepathyClient = new Lang.Class({
             botname: room.channel.target_contact.alias,
             command: command,
             username: username || room.channel.connection.self_contact.alias,
+            usernameSupported: username != null,
             password: password
         };
         this._pendingBotPasswords.set(accountPath, data);
